@@ -6,20 +6,23 @@ from typing import Union
 
 def get_ticker_filings(
     symbol: str,
-    start_date: str = datetime.today().replace(day=1).strftime("%Y-%m-%d"),
-    end_date: str = datetime.today().strftime("%Y-%m-%d"),
+    fromDate: str = datetime.today().replace(day=1).strftime("%Y-%m-%d"),
+    toDate: str = datetime.today().strftime("%Y-%m-%d"),
     limit: int = 100,
 ) -> Union[dict, None]:
     """
     Parameters:
         symbol - ticker symbol from tsx, no prefix
+        fromDate - start date to grab documents
+        toDate - end date to grab documents
+        limit - max number of documents to retrieve
     Returns:
         dict - :ref:`Quote By Symbol <quote_by_symbol_query>`
     """
     payload = GQL.get_company_filings_payload
     payload["variables"]["symbol"] = symbol
-    payload["variables"]["start_date"] = start_date
-    payload["variables"]["end_date"] = end_date
+    payload["variables"]["fromDate"] = fromDate
+    payload["variables"]["toDate"] = toDate
     payload["variables"]["limit"] = limit
     url = "https://app-money.tmx.com/graphql"
     r = requests.post(
@@ -41,7 +44,7 @@ def get_ticker_filings(
 
 
 if __name__ == "__main__":
-    import json
-    import os
-
-    cmc = get_ticker_filings("ART")
+    art = get_ticker_filings(
+        "ART", start_date="2015-11-11", end_date="2020-11-11", limit=108
+    )
+    print(art)
